@@ -8,11 +8,11 @@ from .dataset_definition import DatasetDefinition
 from .quality_manager_definition import QualityManagerDefinition
 
 
-class Config:  
+class Config:
     """
     Wrapper for the pipeline configuration file.
 
-    Note: in most cases, ``Config.load(filepath)`` should be used to 
+    Note: in most cases, ``Config.load(filepath)`` should be used to
     instantiate the Config class.
 
     :param dictionary: The pipeline configuration file as a dictionary.
@@ -24,10 +24,14 @@ class Config:
         dataset_dict = dictionary.get(Keys.DATASET_DEFINITION)
         quality_managers_dict = dictionary.get(Keys.QUALITY_MANAGEMENT, {})
         self.pipeline_definition = PipelineDefinition(pipeline_dict)
-        self.dataset_definition = DatasetDefinition(dataset_dict, self.pipeline_definition.output_datastream_name)
+        self.dataset_definition = DatasetDefinition(
+            dataset_dict, self.pipeline_definition.output_datastream_name
+        )
         self.quality_managers = self._parse_quality_managers(quality_managers_dict)
 
-    def _parse_quality_managers(self, dictionary: Dict) -> Dict[str, QualityManagerDefinition]:        
+    def _parse_quality_managers(
+        self, dictionary: Dict
+    ) -> Dict[str, QualityManagerDefinition]:
         """Extracts QualityManagerDefinitions from the config file.
 
         :param dictionary: The quality_management dictionary.
@@ -37,7 +41,9 @@ class Config:
         """
         quality_managers: Dict[str, QualityManagerDefinition] = {}
         for manager_name, manager_dict in dictionary.items():
-            quality_managers[manager_name] = QualityManagerDefinition(manager_name, manager_dict)
+            quality_managers[manager_name] = QualityManagerDefinition(
+                manager_name, manager_dict
+            )
         return quality_managers
 
     @classmethod
@@ -56,7 +62,7 @@ class Config:
         config = dict()
         for filepath in filepaths:
             Config.lint_yaml(filepath)
-            with open(filepath, 'r') as file:
+            with open(filepath, "r") as file:
                 dict_list = list(yaml.safe_load_all(file))
                 for dictionary in dict_list:
                     config.update(dictionary)
@@ -70,10 +76,14 @@ class Config:
         :type filename: str
         :raises Exception: Raises an exception if an error is found.
         """
-        conf = YamlLintConfig('{"extends": "relaxed", "rules": {"line-length": "disable", "trailing-spaces": "disable", "empty-lines": "disable", "new-line-at-end-of-file": "disable"}}')
+        conf = YamlLintConfig(
+            '{"extends": "relaxed", "rules": {"line-length": "disable", "trailing-spaces": "disable", "empty-lines": "disable", "new-line-at-end-of-file": "disable"}}'
+        )
         with open(filename) as file:
             gen = linter.run(file, conf)
             errors = [error for error in gen if error.level == "error"]
             if errors:
                 errors = "\n".join("\t\t" + str(error) for error in errors)
-                raise Exception(f"Syntax errors found in yaml file {filename}: \n{errors}")
+                raise Exception(
+                    f"Syntax errors found in yaml file {filename}: \n{errors}"
+                )
